@@ -28,7 +28,7 @@ if TYPE_CHECKING:
     try:
         from typing import Protocol
     except ImportError:
-        from typing_extensions import Protocol  # type: ignore[misc]
+        from typing_extensions import Protocol  # type: ignore
 else:
     Protocol = object
 
